@@ -20,129 +20,107 @@ np.seterr(divide='ignore', invalid='ignore')
 
 ' a function for calculating the Similarity/Correlation Coefficient between behavioral data and EEG/MEG/fNIRS data'
 
-def bhvANDeeg_corr(bhv_data, eeg_data, sub_opt=0, bhv_data_opt=1, chl_opt=0, time_opt=0, time_win=5, method="spearman", rescale=False):
+def bhvANDeeg_corr(bhv_data, eeg_data, sub_opt=0, chl_opt=0, time_opt=0, time_win=5, time_step=5, method="spearman", rescale=False):
 
     """
     Calculate the Similarities between behavioral data and EEG/MEG/fNIRS data
 
-    Parameters
-    ----------
-    bhv_data : array
-        If bhv_data_opt=0, the shape must be [n_cons, n_subs].
-        If bhv_data_opt=1, the shape of bhv_data must be [n_cons, n_subs, n_trials].
-        n_cons, n_subs & n_trials represent the number of conidtions, the number of subjects & the number of trials,
-        respectively.
-    eeg_data : array
-        The EEG/MEG/fNIRS data.
-        The shape of EEGdata must be [n_cons, n_subs, n_trials, n_chls, n_ts].
-        n_cons, n_subs, n_trials, n_chls & n_ts represent the number of conidtions, the number of subjects, the number
-        of trials, the number of channels & the number of time-points, respectively.
-    """
-
-
-
-    """
-    Calculate the Representational Dissimilarity Matrix(Matrices) - RDM(s) for behavioral data
-
     Parameters
     ----------
     bhv_data : array
         The behavioral data.
-        If data_opt=0, the shape must be [n_cons, n_subs].
-        If data_opt=1, the shape of bhv_data must be [n_cons, n_subs, n_trials].
+        The shape of bhv_data must be [n_cons, n_subs, n_trials].
         n_cons, n_subs & n_trials represent the number of conidtions, the number of subjects & the number of trials,
         respectively.
-    sub_opt : int 0 or 1. Default is 0.
-        Calculate the RDM for each subject or not.
-        If sub_opt=0, return only one RDM based on all data.
-        If sub_opt=1, return n_subs RDMs based on each subject's data
-    data_opt : int 0 or 1. Default if 0.
-        Select the type of input data, ignoring the effect of trials or not.
-        If data_opt=0, one subejct under one conditions relates to one value, ignoring the effect of trials.
-        If data_opt=1, each trial relates to a value.
-
-    Returns
-    -------
-    RDM(s) : array
-        The behavioral RDM.
-        If sub_opt=0, return only one RDM. The shape is [n_cons, n_cons].
-        If sub_opt=1, return n_subs RDMs. The shape is [n_subs, n_cons, n_cons].
-
-    Notes
-    -----
-    This function can also be used to calculate the RDM for computational simulation data
-    """
-
-    """
-    Calculate the Representational Dissimilarity Matrix(Matrices) - RDM(s) for EEG/MEG/fNIRS data
-
-    Parameters
-    ----------
     eeg_data : array
         The EEG/MEG/fNIRS data.
         The shape of EEGdata must be [n_cons, n_subs, n_trials, n_chls, n_ts].
         n_cons, n_subs, n_trials, n_chls & n_ts represent the number of conidtions, the number of subjects, the number
         of trials, the number of channels & the number of time-points, respectively.
     sub_opt : int 0 or 1. Default is 0.
-        Calculate the RDM for each subject or not.
-        If sub_opt=0, return only one RDM based on all data.
-        If sub_opt=1, return n_subs RDMs based on each subject's data
+        Calculate the RDM & similarities for each subject or not.
+        If sub_opt=0, calculating based on all data.
+        If sub_opt=1, calculating based on each subject's data, respectively.
     chl_opt : int 0 or 1. Default is 0.
-        Calculate the RDM for each channel or not.
-        If chl_opt=0, calculate the RDM based on all channels'data.
-        If chl_opt=1, calculate the RDMs based on each channel's data respectively.
+        Calculate the RDM & similarities for each channel or not.
+        If chl_opt=0, calculating based on all channels' data.
+        If chl_opt=1, calculating based on each channel's data respectively.
     time_opt : int 0 or 1. Default is 0.
-        Calculate the RDM for each time-point
-        If time_opt=0, calculate the RDM based on whole time-points' data.
-        If time_opt=1, calculate the RDMs based on each time-points respectively.
-    time_win : int. Default is 5.
-        Set a time-window for calculating the RDM for different time-points.
+        Calculate the RDM & similarities for each time-point or not
+        If time_opt=0, calculating based on whole time-points' data.
+        If time_opt=1, calculating based on each time-points respectively.
+    time_win : Default is 5.
+        Set a time-window for calculating the RDM & similarities for different time-points.
+        Only when time_opt=1, time_win works.
         If time_win=5, that means each calculation process based on 5 time-points.
-        This is also a processing of downsampling.
+    time_step : int. Default is 5.
+        The time step size for each time of calculating.
+        Only when time_opt=1, time_step works.
+    method : string 'spearman' or 'pearson' or 'kendall' or 'similarity' or 'distance'. Default is 'spearman'.
+        The method to calculate the similarities.
+        If method='spearman', calculate the Spearman Correlations. If method='pearson', calculate the Pearson
+        Correlations. If methd='kendall', calculate the Kendall tau Correlations. If method='similarity', calculate the
+        Cosine Similarities. If method='distance', calculate the Euclidean Distances.
+    rescale : bool True or False.
+        Rescale the values in RDM or not. Here, the maximum-minimum method is used to rescale the values except for the
+        values on the diagnal.
 
     Returns
     -------
-    RDM(s) : array
-        The EEG/MEG/fNIR RDM.
-        If sub_opt=0 & chl_opt=0 & time_opt=0, return only one RDM.
-            The shape is [n_cons, n_cons].
-        If sub_opt=0 & chl_opt=0 & time_opt=1, return int(n_ts/time_win) RDM.
-            The shape is [int(n_ts/time_win), n_cons, n_cons].
-        If sub_opt=0 & chl_opt=1 & time_opt=0, return n_chls RDM.
-            The shape is [n_chls, n_cons, n_cons].
-        If sub_opt=0 & chl_opt=1 & time_opt=1, return n_chls*int(n_ts/time_win) RDM.
-            The shape is [n_chls, int(n_ts/time_win), n_cons, n_cons].
-        If sub_opt=1 & chl_opt=0 & time_opt=0, return n_subs RDM.
-            The shape is [n_subs, n_cons, n_cons].
-        If sub_opt=1 & chl_opt=0 & time_opt=1, return n_subs*int(n_ts/time_win) RDM.
-            The shape is [n_subs, int(n_ts/time_win), n_cons, n_cons].
-        If sub_opt=1 & chl_opt=1 & time_opt=0, return n_subs*n_chls RDM.
-            The shape is [n_subs, n_chls, n_cons, n_cons].
-        If sub_opt=1 & chl_opt=1 & time_opt=1, return n_subs*n_chls*int(n_ts/time_win) RDM.
-            The shape is [n_subs, n_chls, int(n_ts/time_win), n_cons, n_cons].
+    corrs : array
+        The similarities between behavioral data and EEG/MEG/fNIRS data
+        If sub_opt=0 & chl_opt=0 & time_opt=0, return one corr result.
+            The shape of corrs is [2], a r-value and a p-value. If method='similarity' or method='distance', the
+            p-value is 0.
+        If sub_opt=0 & chl_opt=0 & time_opt=1, return int((n_ts-time_win)/time_step)+1 corrs result.
+            The shape of corrs is int((n_ts-time_win)/time_step)+1. 2 represents a r-value and a p-value. If
+            method='similarity' or method='distance', the p-values are all 0.
+        If sub_opt=0 & chl_opt=1 & time_opt=0, return n_chls corrs result.
+            The shape of corrs is [n_chls, 2]. 2 represents a r-value and a p-value. If method='similarity' or
+            method='distance', the p-values are all 0.
+        If sub_opt=0 & chl_opt=1 & time_opt=1, return n_chls*(int((n_ts-time_win)/time_step)+1) corrs result.
+            The shape of corrs is [n_chls, int((n_ts-time_win)/time_step)+1, 2]. 2 represents a r-value and a p-value.
+            If method='similarity' or method='distance', the p-values are all 0.
+        If sub_opt=1 & chl_opt=0 & time_opt=0, return n_subs corr result.
+            The shape of corrs is [n_subs, 2], a r-value and a p-value. If method='similarity' or method='distance',
+            the p-values are all 0.
+        If sub_opt=1 & chl_opt=0 & time_opt=1, return n_subs*(int((n_ts-time_win)/time_step)+1) corrs result.
+            The shape of corrs is [n_subs, int((n_ts-time_win)/time_step)+1, 2]. 2 represents a r-value and a p-value.
+            If method='similarity' or method='distance', the p-values are all 0.
+        If sub_opt=1 & chl_opt=1 & time_opt=0, return n_subs*n_chls corrs result.
+            The shape of corrs is [n_subs, n_chls, 2]. 2 represents a r-value and a p-value. If method='similarity' or
+            method='distance', the p-values are all 0.
+        If sub_opt=1 & chl_opt=1 & time_opt=1, return n_subs*n_chls*(int((n_ts-time_win)/time_step)+1) corrs result.
+            The shape of corrs is [n_subs, n_chls, int((n_ts-time_win)/time_step)+1, 2]. 2 represents a r-value and a
+            p-value. If method='similarity' or method='distance', the p-values are all 0.
     """
 
-
+    # get the number of subjects
     subs = np.shape(bhv_data)[1]
+    # get the number of channels
     chls = np.shape(eeg_data)[3]
-    ts = int(np.shape(eeg_data)[4]/time_win)
+    # get the number of time-points for calculating
+    ts = np.shape(eeg_data)[4]
+    ts = int((ts-time_win)/time_step)+1
 
     if sub_opt == 1:
 
-        if bhv_data_opt == 0:
-
-            return None
-
-        # if bhv_data_opt=1
-
-        bhv_rdms = bhvRDM(bhv_data, sub_opt=sub_opt, data_opt=bhv_data_opt)
+        # calculate the bhv_rdm
+        bhv_rdms = bhvRDM(bhv_data, sub_opt=sub_opt)
 
         if chl_opt == 0:
 
             if time_opt == 0:
-                eeg_rdms = eegRDM(eeg_data, time_win=time_win, sub_opt=sub_opt, chl_opt=chl_opt, time_opt=time_opt)
+
+                # sub_opt=1 & chl_opt=0 & time_opt=0
+
+                # calculate the eeg_rdms
+                eeg_rdms = eegRDM(eeg_data, sub_opt=sub_opt, chl_opt=chl_opt, time_opt=time_opt)
+
+                # initialize the corrs
                 corrs = np.zeros([subs, 2], dtype=np.float64)
 
+                # calculate the corrs
                 for i in range(subs):
 
                     if method == "spearman":
@@ -158,12 +136,15 @@ def bhvANDeeg_corr(bhv_data, eeg_data, sub_opt=0, bhv_data_opt=1, chl_opt=0, tim
 
                 return corrs
 
-            # if time_opt=1
+            # sub_opt=1 & chl_opt=0 & time_opt=1
 
-            eeg_rdms = eegRDM(eeg_data, sub_opt=sub_opt, chl_opt=chl_opt, time_opt=time_opt)
+            # calculate the eeg_rdms
+            eeg_rdms = eegRDM(eeg_data, sub_opt=sub_opt, chl_opt=chl_opt, time_opt=time_opt, time_win=time_win, time_step=time_step)
 
+            # initialize the corrs
             corrs = np.zeros([subs, ts, 2], dtype=np.float64)
 
+            # calculate the corrs
             for i in range(subs):
                 for j in range(ts):
 
@@ -180,12 +161,36 @@ def bhvANDeeg_corr(bhv_data, eeg_data, sub_opt=0, bhv_data_opt=1, chl_opt=0, tim
 
             return corrs
 
-        # chl_opt=1
-
         if time_opt == 1:
-            return None
 
-        # time_opt=0
+            #  sub_opt=1 & chl_opt=1 & time_opt=1
+
+            # calculate the eeg_rdms
+            eeg_rdms = eegRDM(eeg_data, sub_opt=sub_opt, chl_opt=chl_opt, time_opt=time_opt, time_win=time_win, time_step=time_step)
+
+            # initialize the corrs
+            corrs = np.zeros([subs, chls, ts, 2], dtype=np.float64)
+
+            # calculate the corrs
+            for i in range(subs):
+                for j in range(chls):
+                    for k in range(ts):
+
+                        if method == "spearman":
+                            corrs[i, j, k] = rdm_correlation_spearman(bhv_rdms[i], eeg_rdms[i, j, k], rescale=rescale)
+                        elif method == "pearson":
+                            corrs[i, j, k] = rdm_correlation_pearson(bhv_rdms[i], eeg_rdms[i, j, k], rescale=rescale)
+                        elif method == "kendall":
+                            corrs[i, j, k] = rdm_correlation_kendall(bhv_rdms[i], eeg_rdms[i, j, k], rescale=rescale)
+                        elif method == "similarity":
+                            corrs[i, j, k, 0] = rdm_similarity(bhv_rdms[i], eeg_rdms[i, j, k], rescale=rescale)
+                        elif method == "distance":
+                            corrs[i, j, k, 0] = rdm_distance(bhv_rdms[i], eeg_rdms[i, j, k], rescale=rescale)
+
+            return corrs
+
+
+        # sub_opt=1 & chl_opt=1 & time_opt=0
 
         eeg_rdms = eegRDM(eeg_data, sub_opt=sub_opt, chl_opt=chl_opt, time_opt=time_opt)
 
@@ -209,14 +214,21 @@ def bhvANDeeg_corr(bhv_data, eeg_data, sub_opt=0, bhv_data_opt=1, chl_opt=0, tim
 
     # if sub_opt=0
 
-    bhv_rdm = bhvRDM(bhv_data, sub_opt=sub_opt, data_opt=bhv_data_opt)
+    bhv_rdm = bhvRDM(bhv_data, sub_opt=sub_opt)
 
     if chl_opt == 1:
 
         if time_opt == 1:
-            eeg_rdms = eegRDM(eeg_data, sub_opt=sub_opt, chl_opt=chl_opt, time_opt=time_opt)
+
+            # sub_opt = 0 & chl_opt = 1 & time_opt = 1
+
+            # calculate the eeg_rdms
+            eeg_rdms = eegRDM(eeg_data, sub_opt=sub_opt, chl_opt=chl_opt, time_opt=time_opt, time_win=time_win, time_step=time_step)
+
+            # initialize the corrs
             corrs = np.zeros([chls, ts, 2], dtype=np.float64)
 
+            # calculate the corrs
             for i in range(chls):
                 for j in range(ts):
 
@@ -233,12 +245,15 @@ def bhvANDeeg_corr(bhv_data, eeg_data, sub_opt=0, bhv_data_opt=1, chl_opt=0, tim
 
             return corrs
 
-        # if time_opt=0
+        # sub_opt=0 & chl_opt=1 & time_opt=0
 
+        # calculate the eeg_rdms
         eeg_rdms = eegRDM(eeg_data, sub_opt=sub_opt, chl_opt=chl_opt, time_opt=time_opt)
 
+        # initialize the corrs
         corrs = np.zeros([chls, 2], dtype=np.float64)
 
+        # calculate the corrs
         for i in range(chls):
 
             if method == "spearman":
@@ -258,10 +273,15 @@ def bhvANDeeg_corr(bhv_data, eeg_data, sub_opt=0, bhv_data_opt=1, chl_opt=0, tim
 
     if time_opt == 1:
 
-        eeg_rdms = eegRDM(eeg_data, sub_opt=0, chl_opt=0, time_opt=1)
+        # sub_opt=0 & chl_opt=0 & time_opt=1
 
+        # calculate the eeg_rdms
+        eeg_rdms = eegRDM(eeg_data, sub_opt=sub_opt, chl_opt=chl_opt, time_opt=time_opt, time_win=time_win, time_step=time_step)
+
+        # initialize the corrs
         corrs = np.zeros([ts, 2], dtype=np.float64)
 
+        # calculate the corrs
         for i in range(ts):
 
             if method == "spearman":
@@ -277,12 +297,15 @@ def bhvANDeeg_corr(bhv_data, eeg_data, sub_opt=0, bhv_data_opt=1, chl_opt=0, tim
 
         return corrs
 
-    # if time_opt=0
+    # sub_opt=0 & chl_opt=0 & time_opt=0
 
-    eeg_rdm = eegRDM(eeg_data, sub_opt=0, chl_opt=0, time_opt=0)
+    # calculate the eeg_rdms
+    eeg_rdm = eegRDM(eeg_data, sub_opt=sub_opt, chl_opt=chl_opt, time_opt=time_opt)
 
+    # initialize the corrs
     corr = np.zeros([2], dtype=np.float64)
 
+    # calculate the corrs
     if method == "spearson":
         corr = rdm_correlation_spearman(bhv_rdm, eeg_rdm, rescale=rescale)
     elif method == "pearson":
@@ -299,25 +322,85 @@ def bhvANDeeg_corr(bhv_data, eeg_data, sub_opt=0, bhv_data_opt=1, chl_opt=0, tim
 
 ' a function for calculating the Similarity/Correlation Cosfficient between behavioral data and sEEG/ECoG/eletricophysiological data'
 
-def bhvANDecog_corr(bhv_data, ele_data, time_win=5, ecog_opt="allin", method="spearman", rescale=False):
+def bhvANDecog_corr(bhv_data, ele_data, time_win=5, time_step=5, ecog_opt="allin", method="spearman", rescale=False):
+
+    """
+    Calculate the Similarities between behavioral data and sEEG/ECoG/eletricophysiological data
+
+    Parameters
+    ----------
+    bhv_data : array
+
+        The shape of bhv_data must be [n_cons, n_trials].
+        n_cons, n_subs & n_trials represent the number of conidtions, the number of subjects & the number of trials,
+        respectively.
+    ele_data : array
+        The ECoG/sEEG/electrophysiology data.
+        The shape of EEGdata must be [n_cons, n_trials, n_chls, n_ts].
+        n_cons, n_trials, n_chls & n_ts represent the number of conidtions, the number of trials,
+        the number of channels & the number of time-points, respectively.
+    time_win : Default is 5.
+        Set a time-window for calculating the RDM & similarities for different time-points.
+        Only when time_opt=1, time_win works.
+        If time_win=5, that means each calculation process based on 5 time-points.
+    time_step : int. Default is 5.
+        The time step size for each time of calculating.
+        Only when time_opt=1, time_step works.
+    ecog_opt : string 'channel', 'time' or 'all'. Default is 'all'.
+        Calculate the RDM for each channel or for each time-point or for the whole data.
+        If ecog_opt='channel', return n_chls RDMs based on each channel's data.
+        If ecog_opt='time', return int((n_ts-time_win)/time_step)+1 RDMs based on each time-point's data respectively.
+        If ecog_opt='allin', return only one RDM based on all data
+    method : string 'spearman' or 'pearson' or 'kendall' or 'similarity' or 'distance'. Default is 'spearman'.
+        The method to calculate the similarities.
+        If method='spearman', calculate the Spearman Correlations. If method='pearson', calculate the Pearson
+        Correlations. If methd='kendall', calculate the Kendall tau Correlations. If method='similarity', calculate the
+        Cosine Similarities. If method='distance', calculate the Euclidean Distances.
+    rescale : bool True or False.
+        Rescale the values in RDM or not. Here, the maximum-minimum method is used to rescale the values except for the
+        values on the diagnal.
+
+    Returns
+    -------
+    corrs : array
+        The similarities between behavioral data and ECoG/sEEG/electrophysiology.
+        If opt='channel', return n_chls corrs result.
+            The shape of corrs is [n_chls, 2]. 2 represents a r-value and a p-value. If method='similarity' or
+            method='distance', the p-values are all 0.
+        If opt='time', return int(n_ts/time_win) corrs result.
+            The shape of corrs is [int((n_ts-time_win)/time_step)+1, 2]. 2 represents a r-value and a p-value. If
+            method='similarity' or method='distance', the p-values are all 0.
+        If opt='all', return one corr result.
+            The shape of corrs is [2], a r-value and a p-value. If method='similarity' or method='distance',
+            the p-value is 0.
+    """
 
     # sub_opt = 1, bhv_data here belongs to one subject, and its shape must be : [cons, trials]
 
+    # get the number of conditions & the number of trials
     cons, trials = np.shape(bhv_data)
-    ts = np.shape(ele_data)[3]
 
+    # shape of bhv_data: [cons, trials] -> [cons, subs, trials] & subs=1
     bhv_data = np.reshape(bhv_data, [cons, 1, trials])
 
-    bhv_rdm = np.reshape(bhvRDM(bhv_data, sub_opt=1, data_opt=1), [cons, cons])
+    # calculate bhv_rdm
+    bhv_rdm = bhvRDM(bhv_data)
+
+
+    # ecog_opt='channel'
 
     if ecog_opt == "channel":
 
+        # calculate the ecog_rdms
         ecog_rdms = ecogRDM(ele_data, opt="channel")
 
+        # get the number of channels
         chls_num = np.shape(ele_data)[2]
 
+        # initialize the corrs
         corrs = np.zeros([chls_num, 2], dtype=np.float64)
 
+        # get the corrs
         for i in range(chls_num):
 
             if method == "spearman":
@@ -333,14 +416,21 @@ def bhvANDecog_corr(bhv_data, ele_data, time_win=5, ecog_opt="allin", method="sp
 
         return corrs
 
+    # ecog_opt='time'
+
     elif ecog_opt == "time":
 
-        ecog_rdms = ecogRDM(ele_data, time_win=5, opt="time")
+        # calculate the ecog_rdms
+        ecog_rdms = ecogRDM(ele_data, time_win=time_win, time_step=time_step, opt="time")
 
-        ts = int(np.shape(ele_data)[3]/time_win)
+        # get the number of time-points for calculating
+        ts = np.shape(ele_data)[3]
+        ts = int((ts-time_win)/time_step)+1
 
+        # initialize the corrs
         corrs = np.zeros([ts, 2], dtype=np.float64)
 
+        # calculate the corrs
         for i in range(ts):
 
             if method == "spearman":
@@ -356,12 +446,15 @@ def bhvANDecog_corr(bhv_data, ele_data, time_win=5, ecog_opt="allin", method="sp
 
         return corrs
 
-    # if ecog_opt="allin"
+    # ecog_opt="allin"
 
+    # calculate the ecog_rdm
     ecog_rdm = ecogRDM(ele_data, opt="allin")
 
+    # initialize the corr
     corr = np.zeros([2], dtype=np.float64)
 
+    # calculate the corr
     if method == "spearman":
         corr = rdm_correlation_spearman(bhv_rdm, ecog_rdm, rescale=rescale)
     elif method == "pearson":
@@ -376,48 +469,83 @@ def bhvANDecog_corr(bhv_data, ele_data, time_win=5, ecog_opt="allin", method="sp
     return corr
 
 
-' a function for calculating the Similarity/Correlation Cosfficient between behavioral data and fMRI data'
+' a function for calculating the Similarity/Correlation Cosfficient between behavioral data and fMRI data for searchlight'
 
-def bhvANDfmri_corr(bhv_data, fmri_data, bhv_data_opt=1, ksize=[3, 3, 3], strides=[1, 1, 1], method="spearman", rescale=False):
-    # sub_opt=1
+def bhvANDfmri_corr(bhv_data, fmri_data, ksize=[3, 3, 3], strides=[1, 1, 1], method="spearman", rescale=False):
 
-    if bhv_data_opt == 0:
-        bhv_rdm = bhvRDM(bhv_data, sub_opt=0, data_opt=0)
+    """
+    Calculate the Similarities between behavioral data and fMRI data for searchlight
 
-    # if bhv_data_opt=1
-    else:
-        bhv_rdm = bhvRDM(bhv_data, sub_opt=0, data_opt=1)
+    Parameters
+    ----------
+    bhv_data : array
+        The shape of bhv_data must be [n_cons, n_subs, n_trials].
+        n_cons, n_subs & n_trials represent the number of conidtions, the number of subjects & the number of trials,
+        respectively.
+    fmri_data : array
+        The fmri data.
+        The shape of fmri_data must be [n_cons, n_subs, n_chls, nx, ny, nz].
+        n_cons, n_chls, nx, ny, nz represent the number of conidtions, the number of channels &
+        the size of fMRI-img, respectively.
+    ksize : array or list [kx, ky, kz]. Default is [3, 3, 3].
+        The size of the fMRI-img. nx, ny, nz represent the number of voxels along the x, y, z axis
+    strides : array or list [sx, sy, sz]. Default is [1, 1, 1].
+        The strides for calculating along the x, y, z axis.
+    method : string 'spearman' or 'pearson' or 'kendall' or 'similarity' or 'distance'. Default is 'spearman'.
+        The method to calculate the similarities.
+        If method='spearman', calculate the Spearman Correlations. If method='pearson', calculate the Pearson
+        Correlations. If methd='kendall', calculate the Kendall tau Correlations. If method='similarity', calculate the
+        Cosine Similarities. If method='distance', calculate the Euclidean Distances.
+    rescale : bool True or False.
+        Rescale the values in RDM or not. Here, the maximum-minimum method is used to rescale the values except for the
+        values on the diagnal.
+
+    Returns
+    -------
+    corrs : array
+        The similarities between behavioral data and fMRI data for searchlight.
+        The shape of RDMs is [n_x, n_y, n_z, 2]. n_x, n_y, n_z represent the number of calculation units for searchlight
+        along the x, y, z axis and 2 represents a r-value and a p-value.
+    """
+
+    # calculate the bhv_rdm
+    bhv_rdm = bhvRDM(bhv_data, sub_opt=0)
 
     print("****************")
     print("get behavior RDM")
     print(bhv_rdm)
 
+    # calculate the fmri_rdms for searchlight
     fmri_rdms = fmriRDM(fmri_data, ksize=ksize, strides=strides)
 
     print("****************")
     print("get fMRI RDM")
     print(np.shape(fmri_rdms))
 
-    cons = np.shape(bhv_data)[0]
-
+    # get the size of the fMRI-img
     nx = np.shape(fmri_data)[2]
     ny = np.shape(fmri_data)[3]
     nz = np.shape(fmri_data)[4]
 
+    # the size of the calculation units for searchlight
     kx = ksize[0]
     ky = ksize[1]
     kz = ksize[2]
 
+    # strides for calculating along the x, y, z axis
     sx = strides[0]
     sy = strides[1]
     sz = strides[2]
 
+    # calculate the number of the calculation units in the x, y, z directions
     n_x = int((nx - kx) / sx) + 1
     n_y = int((ny - ky) / sy) + 1
     n_z = int((nz - kz) / sz) + 1
 
+    # initialize the corrs
     corrs = np.full([n_x, n_y, n_z, 2], np.nan)
 
+    # calculate the corrs
     for i in range(n_x):
         for j in range(n_y):
             for k in range(n_z):
@@ -438,39 +566,89 @@ def bhvANDfmri_corr(bhv_data, fmri_data, bhv_data_opt=1, ksize=[3, 3, 3], stride
     return corrs
 
 
-' a function for calculating the Similarity/Correlation Cosfficient between behavioral EEG/MEG/fNIRS and fMRI data'
+' a function for calculating the Similarity/Correlation Cosfficient between behavioral EEG/MEG/fNIRS and fMRI data for searchlight'
 
 def eegANDfmri_corr(eeg_data, fmri_data, chl_opt=0, ksize=[3, 3, 3], strides=[1, 1, 1], method="spearman", rescale=False):
-    # sub_opt=0, time_opt=0
 
+    """
+    Calculate the Similarities between EEG/MEG/fNIRS data and fMRI data for searchligt
+
+    Parameters
+    ----------
+    eeg_data : array
+        The EEG/MEG/fNIRS data.
+        The shape of EEGdata must be [n_cons, n_subs, n_trials, n_chls, n_ts].
+        n_cons, n_subs, n_trials, n_chls & n_ts represent the number of conidtions, the number of subjects, the number
+        of trials, the number of channels & the number of time-points, respectively.
+    fmri_data : array
+        The fmri data.
+        The shape of fmri_data must be [n_cons, n_subs, n_chls, nx, ny, nz].
+        n_cons, n_chls, nx, ny, nz represent the number of conidtions, the number of channels &
+        the size of fMRI-img, respectively.
+    chl_opt : int 0 or 1. Default is 0.
+        Calculate the RDM & similarities for each channel or not.
+        If chl_opt=0, calculating based on all channels' data.
+        If chl_opt=1, calculating based on each channel's data respectively.
+    ksize : array or list [kx, ky, kz]. Default is [3, 3, 3].
+        The size of the fMRI-img. nx, ny, nz represent the number of voxels along the x, y, z axis
+    strides : array or list [sx, sy, sz]. Default is [1, 1, 1].
+        The strides for calculating along the x, y, z axis.
+    method : string 'spearman' or 'pearson' or 'kendall' or 'similarity' or 'distance'. Default is 'spearman'.
+        The method to calculate the similarities.
+        If method='spearman', calculate the Spearman Correlations. If method='pearson', calculate the Pearson
+        Correlations. If methd='kendall', calculate the Kendall tau Correlations. If method='similarity', calculate the
+        Cosine Similarities. If method='distance', calculate the Euclidean Distances.
+    rescale : bool True or False.
+        Rescale the values in RDM or not. Here, the maximum-minimum method is used to rescale the values except for the
+        values on the diagnal.
+
+    Returns
+    -------
+    corrs : array
+        The similarities between EEG/MEG/fNIRS data and fMRI data for searchlight.
+        If chl_opt=1, the shape of RDMs is [n_chls, n_x, n_y, n_z, 2]. n_x, n_y, n_z represent the number of calculation
+        units for searchlight along the x, y, z axis and 2 represents a r-value and a p-value.
+        If chl_opt=0, the shape of RDMs is [n_x, n_y, n_z, 2]. n_x, n_y, n_z represent the number of calculation units
+        for searchlight along the x, y, z axis and 2 represents a r-value and a p-value.
+    """
+
+    # get the size of the fMRI-img
     nx = np.shape(fmri_data)[2]
     ny = np.shape(fmri_data)[3]
     nz = np.shape(fmri_data)[4]
 
-    cons = np.shape(eeg_data)[0]
-
+    # the size of the calculation units for searchlight
     kx = ksize[0]
     ky = ksize[1]
     kz = ksize[2]
 
+    # strides for calculating along the x, y, z axis
     sx = strides[0]
     sy = strides[1]
     sz = strides[0]
 
+    # calculate the number of the calculation units in the x, y, z directions
     n_x = int((nx - kx) / sx) + 1
     n_y = int((ny - ky) / sy) + 1
     n_z = int((nz - kz) / sz) + 1
 
+    # calculate the fmri_rdms for searchlight
     fmri_rdms = fmriRDM(fmri_data, ksize=ksize, strides=strides)
 
+    # chl_opt=1
+
     if chl_opt == 1:
 
+        # get the number of channels
         chls = np.shape(eeg_data)[3]
 
+        # get the eeg_rdms
         eeg_rdms = eegRDM(eeg_data, sub_opt=0, chl_opt=1, time_opt=0)
 
+        # initialize the corrs
         corrs = np.full([chls, n_x, n_y, n_z, 2], np.nan)
 
+        # calculate the corrs
         for j in range(n_x):
             for k in range(n_y):
                 for l in range(n_z):
@@ -489,12 +667,15 @@ def eegANDfmri_corr(eeg_data, fmri_data, chl_opt=0, ksize=[3, 3, 3], strides=[1,
 
         return np.abs(corrs)
 
-    # if chl_opt=0
+    # chl_opt=0
 
+    # get the eeg_rdms
     eeg_rdm = eegRDM(eeg_data, sub_opt=0, chl_opt=0, time_opt=0)
 
+    # initialize the corrs
     corrs = np.full([n_x, n_y, n_z, 2], np.nan)
 
+    # calculate the corrs
     for i in range(n_x):
         for j in range(n_y):
             for k in range(n_z):
