@@ -99,6 +99,28 @@ def rdms_corr(demo_rdm, eeg_rdms, method="spearman", rescale=False):
 
         return corrs
 
+    if len(eeg_rdms.shape) == 3:
+
+        n1 = eeg_rdms.shape[0]
+
+        # initialize the corrs
+        corrs = np.zeros([n1, 2], dtype=np.float64)
+
+        # calculate the corrs
+        for i in range(n1):
+            if method == "spearman":
+                corrs[i] = rdm_correlation_spearman(demo_rdm, eeg_rdms[i], rescale=rescale)
+            elif method == "pearson":
+                corrs[i] = rdm_correlation_pearson(demo_rdm, eeg_rdms[i], rescale=rescale)
+            elif method == "kendall":
+                corrs[i] = rdm_correlation_kendall(demo_rdm, eeg_rdms[i], rescale=rescale)
+            elif method == "similarity":
+                corrs[i, 0] = rdm_similarity(demo_rdm, eeg_rdms[i], rescale=rescale)
+            elif method == "distance":
+                corrs[i, 0] = rdm_distance(demo_rdm, eeg_rdms[i], rescale=rescale)
+
+        return corrs
+
     # initialize the corrs
     corr = np.zeros([2], dtype=np.float64)
 
