@@ -14,7 +14,7 @@ from neurora.rsa_plot import plot_brainrsa_rlts
 
 ' a function for saving the searchlight RSA results as a NIfTI file for fMRI '
 
-def corr_save_nii(corrs, filename, affine, corr_mask=None, size=[60, 60, 60], ksize=[3, 3, 3], strides=[1, 1, 1], p=1, r=0, correct_method=None, plotrlt=True, img_background=None):
+def corr_save_nii(corrs, filename, affine, corr_mask=None, size=[60, 60, 60], ksize=[3, 3, 3], strides=[1, 1, 1], p=1, r=0, correct_method=None, smooth=True, plotrlt=True, img_background=None):
 
     """
     Save the searchlight RSA results as a NIfTI file for fMRI
@@ -51,6 +51,8 @@ def corr_save_nii(corrs, filename, affine, corr_mask=None, size=[60, 60, 60], ks
         If correct_method='FWE', here the FWE-correction will be used. If correct_methd='FDR', here the FDR-correction
         will be used. If correct_method=None, no correction.
         Only when p<1, correct_method works.
+    smooth : boolean True or False
+        Smooth the RSA result or not.
     plotrlt : bool True or False.
         Plot the RSA result automatically or not.
     img_background : None or string. Default if None.
@@ -210,10 +212,12 @@ def corr_save_nii(corrs, filename, affine, corr_mask=None, size=[60, 60, 60], ks
     # save the .nii file for RSA results
     file = nib.Nifti1Image(newimg_nii, affine)
 
-    # smooth the img data of the .nii file
-    file = smooth_img(file, fwhm='fast')
 
-    # save again
+    if smooth == True:
+        # smooth the img data of the .nii file
+        file = smooth_img(file, fwhm='fast')
+
+    # save the result
     nib.save(file, filename)
 
 
