@@ -19,7 +19,7 @@ def rdm_correlation_spearman(RDM1, RDM2, rescale=False):
 
     Parameters
     ----------
-    RDM1 : array [ncons, ncons].
+    RDM1 : array [ncons, ncons]
         The RDM 1.
         The shape of fmri_data must be [n_cons, n_cons].
         n_cons represent the number of conidtions.
@@ -27,7 +27,7 @@ def rdm_correlation_spearman(RDM1, RDM2, rescale=False):
         The RDM 2.
         The shape of fmri_data must be [n_cons, n_cons].
         n_cons represent the number of conidtions.
-    rescale : Boolean True or False.
+    rescale : bool True or False.
         Rescale the values in RDM or not. Here, the maximum-minimum method is used to rescale the values except for the
         values on the diagnal.
 
@@ -43,10 +43,7 @@ def rdm_correlation_spearman(RDM1, RDM2, rescale=False):
     print(cons)
 
     # calculate the number of value above the diagonal in RDM
-    n = 0
-    while cons > 1:
-        n = n + cons - 1
-        cons = cons - 1
+    n = int(cons*(cons-1)/2)
 
     print(np.shape(RDM1))
     print(np.shape(RDM2))
@@ -123,7 +120,7 @@ def rdm_correlation_pearson(RDM1, RDM2, rescale=False):
 
     Parameters
     ----------
-    RDM1 : array [ncons, ncons].
+    RDM1 : array [ncons, ncons]
         The RDM 1.
         The shape of fmri_data must be [n_cons, n_cons].
         n_cons represent the number of conidtions.
@@ -131,7 +128,7 @@ def rdm_correlation_pearson(RDM1, RDM2, rescale=False):
         The RDM 2.
         The shape of fmri_data must be [n_cons, n_cons].
         n_cons represent the number of conidtions.
-    rescale : Boolean True or False.
+    rescale : bool True or False.
         Rescale the values in RDM or not. Here, the maximum-minimum method is used to rescale the values except for the
         values on the diagnal.
 
@@ -146,10 +143,7 @@ def rdm_correlation_pearson(RDM1, RDM2, rescale=False):
     cons = np.shape(RDM1)[0]
 
     # calculate the number of value above the diagonal in RDM
-    n = 0
-    while cons > 1:
-        n = n + cons - 1
-        cons = cons - 1
+    n = int(cons*(cons-1)/2)
 
     if rescale == True:
 
@@ -219,7 +213,7 @@ def rdm_correlation_kendall(RDM1, RDM2, rescale=False):
 
     Parameters
     ----------
-    RDM1 : array [ncons, ncons].
+    RDM1 : array [ncons, ncons]
         The RDM 1.
         The shape of fmri_data must be [n_cons, n_cons].
         n_cons represent the number of conidtions.
@@ -227,7 +221,7 @@ def rdm_correlation_kendall(RDM1, RDM2, rescale=False):
         The RDM 2.
         The shape of fmri_data must be [n_cons, n_cons].
         n_cons represent the number of conidtions.
-    rescale : Boolean True or False.
+    rescale : bool True or False.
         Rescale the values in RDM or not. Here, the maximum-minimum method is used to rescale the values except for the
         values on the diagnal.
 
@@ -242,10 +236,7 @@ def rdm_correlation_kendall(RDM1, RDM2, rescale=False):
     cons = np.shape(RDM1)[0]
 
     # calculate the number of value above the diagonal in RDM
-    n = 0
-    while cons > 1:
-        n = n + cons - 1
-        cons = cons - 1
+    n = int(cons*(cons-1)/2)
 
     if rescale == True:
 
@@ -316,7 +307,7 @@ def rdm_similarity(RDM1, RDM2, rescale=False):
 
     Parameters
     ----------
-    RDM1 : array [ncons, ncons].
+    RDM1 : array [ncons, ncons]
         The RDM 1.
         The shape of fmri_data must be [n_cons, n_cons].
         n_cons represent the number of conidtions.
@@ -324,7 +315,7 @@ def rdm_similarity(RDM1, RDM2, rescale=False):
         The RDM 2.
         The shape of fmri_data must be [n_cons, n_cons].
         n_cons represent the number of conidtions.
-    rescale : Boolean True or False.
+    rescale : bool True or False.
         Rescale the values in RDM or not. Here, the maximum-minimum method is used to rescale the values except for the
         values on the diagnal.
 
@@ -338,10 +329,7 @@ def rdm_similarity(RDM1, RDM2, rescale=False):
     cons = np.shape(RDM1)[0]
 
     # calculate the number of value above the diagonal in RDM
-    n = 0
-    while cons > 1:
-        n = n + cons - 1
-        cons = cons - 1
+    n = int(cons*(cons-1)/2)
 
     if rescale == True:
 
@@ -419,7 +407,7 @@ def rdm_distance(RDM1, RDM2, rescale=False):
 
     Parameters
     ----------
-    RDM1 : array [ncons, ncons].
+    RDM1 : array [ncons, ncons]
         The RDM 1.
         The shape of fmri_data must be [n_cons, n_cons].
         n_cons represent the number of conidtions.
@@ -427,7 +415,7 @@ def rdm_distance(RDM1, RDM2, rescale=False):
         The RDM 2.
         The shape of fmri_data must be [n_cons, n_cons].
         n_cons represent the number of conidtions.
-    rescale : Boolean True or False.
+    rescale : bool True or False.
         Rescale the values in RDM or not. Here, the maximum-minimum method is used to rescale the values except for the
         values on the diagnal.
 
@@ -441,10 +429,7 @@ def rdm_distance(RDM1, RDM2, rescale=False):
     cons = np.shape(RDM1)[0]
 
     # calculate the number of value above the diagonal in RDM
-    n = 0
-    while cons > 1:
-        n = n + cons - 1
-        cons = cons - 1
+    n = int(cons*(cons-1)/2)
 
     if rescale == True:
 
@@ -517,7 +502,7 @@ def rdm_permutation(RDM1, RDM2, iter=1000, rescale=False):
 
     Parameters
     ----------
-    RDM1 : array [ncons, ncons].
+    RDM1 : array [ncons, ncons]
         The RDM 1.
         The shape of fmri_data must be [n_cons, n_cons].
         n_cons represent the number of conidtions.
@@ -527,7 +512,7 @@ def rdm_permutation(RDM1, RDM2, iter=1000, rescale=False):
         n_cons represent the number of conidtions.
     iter : int. Default is 1000.
         The times for iteration.
-    rescale : Boolean True or False.
+    rescale : bool True or False.
         Rescale the values in RDM or not. Here, the maximum-minimum method is used to rescale the values except for the
         values on the diagnal.
 
@@ -541,10 +526,7 @@ def rdm_permutation(RDM1, RDM2, iter=1000, rescale=False):
     cons = np.shape(RDM1)[0]
 
     # calculate the number of value above the diagonal in RDM
-    n = 0
-    while cons > 1:
-        n = n + cons - 1
-        cons = cons - 1
+    n = int(cons*(cons-1)/2)
 
     v1 = np.zeros([n], dtype=np.float64)
     v2 = np.zeros([n], dtype=np.float64)
